@@ -38,6 +38,7 @@ const (
 	flgDNSPropagationRNS        = "dns.propagation-rns"
 	flgDNSResolvers             = "dns.resolvers"
 	flgHTTPTimeout              = "http-timeout"
+	flgTLSSkipVerify            = "tls-skip-verify"
 	flgDNSTimeout               = "dns-timeout"
 	flgPEM                      = "pem"
 	flgPFX                      = "pfx"
@@ -175,6 +176,10 @@ func CreateFlags(defaultPath string) []cli.Flag {
 			Name:  flgHTTPTimeout,
 			Usage: "Set the HTTP timeout value to a specific value in seconds.",
 		},
+		&cli.BoolFlag{
+			Name:  flgTLSSkipVerify,
+			Usage: "Skip the TLS verification of the ACME server.",
+		},
 		&cli.IntFlag{
 			Name:  flgDNSTimeout,
 			Usage: "Set the DNS timeout value to a specific value in seconds. Used only when performing authoritative name server queries.",
