@@ -6,19 +6,13 @@ import (
 	"fmt"
 	"time"
 
+	"github.com/go-acme/lego/v4/challenge"
 	"github.com/go-acme/lego/v4/challenge/dns01"
 	"github.com/go-acme/lego/v4/platform/config/env"
 	"github.com/go-acme/lego/v4/providers/dns/vkcloud/internal"
 	"github.com/gophercloud/gophercloud"
 )
 
-const (
-	defaultIdentityEndpoint = "https://infra.mail.ru/identity/v3/"
-	defaultDNSEndpoint      = "https://mcs.mail.ru/public-dns/v2/dns"
-)
-
-const defaultDomainName = "users"
-
 // Environment variables names.
 const (
 	envNamespace = "VK_CLOUD_"
@@ -37,6 +31,15 @@ const (
 	EnvPollingInterval    = envNamespace + "POLLING_INTERVAL"
 )
 
+const (
+	defaultIdentityEndpoint = "https://infra.mail.ru/identity/v3/"
+	defaultDNSEndpoint      = "https://mcs.mail.ru/public-dns/v2/dns"
+)
+
+const defaultDomainName = "users"
+
+var _ challenge.ProviderTimeout = (*DNSProvider)(nil)
+
 // Config is used to configure the creation of the DNSProvider.
 type Config struct {
 	ProjectID string
